﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Xml;
using Infragistics.Windows.Ribbon;
using System.Xml.Linq;
using System.Windows.Forms;
using System.IO;

namespace RibbonQAT
{
    public static class QATControler
    {
        public static bool LoadQATContent(QuickAccessToolbar qat)
        {
            try
            {
                var targetIDs =
                    from id in XElement.Load(@"QATContent.xml").Elements("TargetId")
                    select id;

                foreach (var targetID in targetIDs)
                {

                    if (targetID != null)
                        if ((string)targetID.FirstAttribute == "Tool")
                        {
                            qat.Items.Add(new QatPlaceholderTool(targetID.Value) { TargetType = QatPlaceholderToolType.Tool });
                        }
                        else
                            qat.Items.Add(new QatPlaceholderTool(targetID.Value) { TargetType = QatPlaceholderToolType.RibbonGroup });
                }   
                return true;
            }
            catch (Exception)
            {
                return false;
            }
        }

        public static bool SaveCatContent(QuickAccessToolbar qat)
        {
            try
            {
                if (!File.Exists("QATContent.xml"))
                {
                    FileStream newFile = new FileStream("QATContent.xml", FileMode.CreateNew);
                    newFile.Close();
                }

                FileStream fs = new FileStream(
                    @"QATContent.xml", 
                    FileMode.OpenOrCreate, 
                    FileAccess.Write, 
                    FileShare.Write);


                XmlTextWriter xml = new XmlTextWriter(fs, Encoding.UTF8);
                xml.WriteStartDocument();
                xml.WriteStartElement("AssociatedTargetIds");
                foreach (QatPlaceholderTool qatPT in qat.Items)
                {
                    if (qatPT.TargetId != null)
                    {
                        //xml.WriteElementString("TargetId", qatPT.TargetId);
                        xml.WriteStartElement("TargetId");
                        xml.WriteAttributeString("Type", qatPT.TargetType.ToString());
                        xml.WriteString(qatPT.TargetId);
                        xml.WriteEndElement();
                    }
                }
                xml.WriteEndElement();
                xml.WriteEndDocument();
                xml.Flush();
                fs.Close();


                return true;
            }
            catch (Exception)
            {
                return false;
            }
        }
    }
}
